@@ -20,7 +20,7 @@ class Company:
 		self.ticker = ticker.upper()
 		results = find_ticker(ticker, self.c)
 		ticker = results[0]
-		company_name = results[1]
+		company_name = results[1].strip()
 		alt_company_name = results[-1]
 		people = []
 		for x in results[2:]:
@@ -38,14 +38,14 @@ def get_terms(ticker):
 	ticker = ticker.upper()
 	results = find_ticker(ticker, c)
 	print(results)
-	alt_company_name = results[-1]
+	alt_company_name = results[-1].strip()
 	ticker = results[0]
 	company_name = results[1]
 	people = []
 	conn.close()
 	NICKNAME_FILE = pkg_resources.resource_filename('ticker_to_searchable_terms', 'DB/Nicknames.db')
 	conn, c = open_connection(NICKNAME_FILE)
-	for x in results[2:]:
+	for x in results[2:-1]:
 		if x != 'NULL':
 			nicknames = find_nicknames(x, c)
 			x = generate_possible_names(x, c)
